pub type Certificate1<TYPES> = SimpleCertificate<TYPES, QuorumData2<TYPES>, SuccessThreshold>;Expand description
Type alias for the new protocol’s phase-1 certificate over QuorumData2
Aliased Type
pub struct Certificate1<TYPES> {
pub data: QuorumData2<TYPES>,
vote_commitment: Commitment<QuorumData2<TYPES>>,
pub view_number: ViewNumber,
pub signatures: Option<<<TYPES as NodeType>::SignatureKey as SignatureKey>::QcType>,
pub _pd: PhantomData<(TYPES, SuccessThreshold)>,
}Fields
data: QuorumData2<TYPES>The data this certificate is for. I.e the thing that was voted on to create this Certificate
vote_commitment: Commitment<QuorumData2<TYPES>>commitment of all the votes this cert should be signed over
view_number: ViewNumberWhich view this QC relates to
signatures: Option<<<TYPES as NodeType>::SignatureKey as SignatureKey>::QcType>assembled signature for certificate aggregation
_pd: PhantomData<(TYPES, SuccessThreshold)>phantom data for THRESHOLD and TYPES