pub type Certificate2<TYPES> = SimpleCertificate<TYPES, Vote2Data<TYPES>, SuccessThreshold>;Expand description
Type alias for the new protocol’s phase-2 certificate over Vote2Data
Aliased Type
pub struct Certificate2<TYPES> {
pub data: Vote2Data<TYPES>,
vote_commitment: Commitment<Vote2Data<TYPES>>,
pub view_number: ViewNumber,
pub signatures: Option<<<TYPES as NodeType>::SignatureKey as SignatureKey>::QcType>,
pub _pd: PhantomData<(TYPES, SuccessThreshold)>,
}Fields
data: Vote2Data<TYPES>The data this certificate is for. I.e the thing that was voted on to create this Certificate
vote_commitment: Commitment<Vote2Data<TYPES>>commitment of all the votes this cert should be signed over
view_number: ViewNumberWhich view this QC relates to
signatures: Option<<<TYPES as NodeType>::SignatureKey as SignatureKey>::QcType>assembled signature for certificate aggregation
_pd: PhantomData<(TYPES, SuccessThreshold)>phantom data for THRESHOLD and TYPES